# Modal Pickup Hudmemos

**Hudmemo** - *A short string displayed to the player in-game*

**Modal** - *Pauses the game, requiring "A" press to continue*

This is a list of pickup locations which are reccomended to be set to `"modalHudmemo":true` to ensure the player can read what they picked up.

- Artifact Temple
- Watery Hall (Charge Beam)
- Research Core
